@@ -7,7 +7,6 @@ expect a full or complete implementation of the ActivityPub API.
 import asyncio
 import json
 import logging
-import mimetypes
 import random
 import uuid
 from typing import Any
@@ -596,19 +595,13 @@ class ActivityPub:
 
         await self.__pre_call_checks()
 
-        file_extension = mimetypes.guess_extension(mime_type)
-        if file_extension is None:
-            raise ClientError(
-                f"Cannot determine file type based on passed in mime-type: {mime_type}"
-            )
-
         headers = {"Authorization": self.authorization}
         url = f"{self.instance}/api/v1/media"
         data = aiohttp.FormData()
         data.add_field(
             name="file",
             value=file,
-            filename=uuid.uuid4().hex + file_extension,
+            filename=uuid.uuid4().hex,
             content_type=mime_type,
         )
         if description:
